==> RcppSMC_0.2.3.tar.gz: RcppSMC/README.md <==
## RcppSMC: Rcpp Bindings for Sequential Monte Carlo

[![Build Status](https://travis-ci.org/rcppsmc/rcppsmc.svg)](https://travis-ci.org/github/rcppsmc/rcppsmc)
[![CI](https://github.com/rcppsmc/rcppsmc/workflows/ci/badge.svg)](https://github.com/rcppsmc/rcppsmc/actions?query=workflow%3Aci)
[![License](https://img.shields.io/badge/license-GPL%20%28%3E=%202%29-brightgreen.svg?style=flat)](https://www.gnu.org/licenses/gpl-2.0.html)
[![CRAN](https://www.r-pkg.org/badges/version/RcppSMC)](https://cran.r-project.org/package=RcppSMC)
[![Downloads](https://cranlogs.r-pkg.org/badges/RcppSMC?color=brightgreen)](https://www.r-pkg.org/pkg/RcppSMC)
[![Last Commit](https://img.shields.io/github/last-commit/rcppsmc/rcppsmc)](https://github.com/rcppsmc/rcppsmc)

### Summary

This package provides R with access to the
[Sequential Monte Carlo Template Classes](https://www.jstatsoft.org/article/view/v030i06/)
by Johansen (Journal of Statistical Software, 2009, v30, i6).

At present, four additional examples have been added, and the first example
from the JSS paper has been extended. Further integration and extensions are
planned.

### More Examples

See the packages [ToyPackage](https://github.com/rcppsmc/ToyPackage) and
[RickerExample](https://github.com/rcppsmc/RickerExample) repositories next
to this one in the [RcppSMC](https://github.com/rcppsmc) organization.

### Help

For support and discussion please make us of the [rcppsmc mailing list](https://groups.google.com/forum/#!forum/rcppsmc).

### Authors

Dirk Eddelbuettel, Adam M. Johansen and Leah F. South

### License

GPL (>= 2)

==> RcppSMC_0.2.4.tar.gz: RcppSMC/README.md <==
## RcppSMC: Rcpp Bindings for Sequential Monte Carlo

[![Build Status](https://travis-ci.org/rcppsmc/rcppsmc.svg)](https://travis-ci.org/github/rcppsmc/rcppsmc)
[![CI](https://github.com/rcppsmc/rcppsmc/workflows/ci/badge.svg)](https://github.com/rcppsmc/rcppsmc/actions?query=workflow%3Aci)
[![License](https://img.shields.io/badge/license-GPL%20%28%3E=%202%29-brightgreen.svg?style=flat)](https://www.gnu.org/licenses/gpl-2.0.html)
[![CRAN](https://www.r-pkg.org/badges/version/RcppSMC)](https://cran.r-project.org/package=RcppSMC)
[![Downloads](https://cranlogs.r-pkg.org/badges/RcppSMC?color=brightgreen)](https://www.r-pkg.org/pkg/RcppSMC)
[![Last Commit](https://img.shields.io/github/last-commit/rcppsmc/rcppsmc)](https://github.com/rcppsmc/rcppsmc)

### Summary

This package provides R with access to the
[Sequential Monte Carlo Template Classes](https://www.jstatsoft.org/article/view/v030i06/)
by Johansen (Journal of Statistical Software, 2009, v30, i6).

At present, four additional examples have been added, and the first example
from the JSS paper has been extended. Further integration and extensions are
planned.

### More Examples

See the packages [ToyPackage](https://github.com/rcppsmc/ToyPackage),
[RickerExample](https://github.com/rcppsmc/RickerExample),
[SVmodelRcppSMC](https://github.com/ilyaZar/SVmodelRcppSMC), and
demo repository [SVmodelExamples](https://github.com/ilyaZar/SVmodelExamples)
next to this one in the [RcppSMC](https://github.com/rcppsmc) organization.

### Help

For support and discussion please make us of the [rcppsmc mailing list](https://groups.google.com/forum/#!forum/rcppsmc).

### Authors

Dirk Eddelbuettel, Adam M. Johansen and Leah F. South

### License

GPL (>= 2)
